@@ -48,7 +48,7 @@ def push(*args):
             updated = '0 files updated, 0 files merged, 0 files removed, 0 files unresolved' not in output
     if updated or 'force' in args:
         if 'pip_update' in args:
-            pip_update('active_apps', restart=False)
+            pip_update(restart=False)
         if 'syncdb' in args:
             syncdb()
         if 'migrate' in args:
