@@ -1,6 +1,6 @@
 #coding: utf-8
 from __future__ import with_statement
-from fabric.api import env, cd, local, run
+from fabric.api import env, cd, local, run, settings
 from fab_deploy.commands import mysqldump
 
 def manage(command, on_server=True):
